# WedgieIntegrator
WedgieIntegrator is an async friendly package for Python which acts as API client toolkit for creating and managing API clients with ease.

## Features

- Simple configuration
- Multiple authentication strategies
- Retry mechanisms
- Asynchronous support
- Detailed logging

## Installation

```bash
pip install WedgieIntegrator
```
